//[mahjong-utils](../../../index.md)/[mahjongutils.hora](../index.md)/[ChitoiHoraHandPattern](index.md)/[ChitoiHoraHandPattern](-chitoi-hora-hand-pattern.md)

# ChitoiHoraHandPattern

[common]\
constructor(pairs: [Set](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-set/index.html)&lt;[Tile](../../mahjongutils.models/-tile/index.md)&gt;, agari: [Tile](../../mahjongutils.models/-tile/index.md), tsumo: [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html), selfWind: [Wind](../../mahjongutils.models/-wind/index.md)? = null, roundWind: [Wind](../../mahjongutils.models/-wind/index.md)? = null)
